@@ -2,6 +2,7 @@
 
 from scipy.stats import norm
 
-
 if __name__ == "__main__":
-    print("bounds of distribution lower: %s, upper: %s" % norm.support())
+    print(
+        "bounds of distribution lower: {}, upper: {}".format(*norm.support())
+    )
