@@ -4,11 +4,11 @@ from __future__ import annotations
 
 import sys
 from pathlib import Path
-from sysconfig import get_platform, get_python_version
 
 import pytest
 from generate_samples import run_command
 
+from cx_Freeze._compat import BUILD_EXE_DIR, EXE_SUFFIX
 from cx_Freeze.winmsvcr import FILES
 
 EXPECTED = (
@@ -31,14 +31,8 @@ EXPECTED = (
     "vcruntime140_threads.dll",
 )
 
-PLATFORM = get_platform()
-PYTHON_VERSION = get_python_version()
-BUILD_EXE_DIR = f"build/exe.{PLATFORM}-{PYTHON_VERSION}"
-
 SAMPLES_DIR = Path(__file__).resolve().parent.parent / "samples"
 BUILD_EXE_CMD = "python setup.py build_exe --silent --excludes=tkinter"
-IS_WINDOWS = sys.platform == "win32"
-SUFFIX = ".exe" if IS_WINDOWS else ""
 
 
 @pytest.mark.skipif(sys.platform != "win32", reason="Windows tests")
@@ -61,7 +55,7 @@ def test_build_exe_with_include_msvcr(
 
     build_exe_dir = datafiles / BUILD_EXE_DIR
 
-    executable = build_exe_dir / f"test_sqlite3{SUFFIX}"
+    executable = build_exe_dir / f"test_sqlite3{EXE_SUFFIX}"
     assert executable.is_file()
     output = run_command(datafiles, executable, timeout=10)
     assert output.startswith("dump.sql created")
@@ -72,6 +66,6 @@ def test_build_exe_with_include_msvcr(
         if any(filter(file.match, EXPECTED))
     ]
     if include_msvcr:
-        assert names is not []
+        assert names != []
     else:
         assert not names
